#!/usr/bin/perl -w

# Copyright 2013, 2014, 2020 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


# Print tikz A,B points as dots.

use strict;
use Math::PlanePath::PythagoreanTree;

use FindBin;
use lib $FindBin::Bin;
use MyPrintwrap ':all';
use MyTriples 'AB_acceptable';


my $x_limit = 300;
my $scale = 1;

print "      % generated by tools/$FindBin::Script\n";

my $path = Math::PlanePath::PythagoreanTree->new (coordinates => 'AB');

$Printwrap = 6;
printwrap("\\fill foreach \\p in {");
$Printwrap += 2;
foreach my $x (0 .. $x_limit) {
  foreach my $y (0 .. $x_limit) {
    my $got = $path->xy_is_visited($x,$y) ? 1 : 0;
    my $want = AB_acceptable($x,$y) ? 1 : 0;
    $got == $want or die;
    if ($got) {
      $x /= $scale;
      $y /= $scale;
      if ($x != int($x)) {
        $x = sprintf '%.4f', $x;
        $x =~ s/0+$//;
      }
      if ($y != int($y)) {
        $y = sprintf '%.4f', $y;
        $y =~ s/0+$//;
      }
      printwrap("($x,$y),");
    }
  }
}
printwrap("}");
printwrap(" { \\p circle[] };\n");
print "      % end generated\n";
1;
