#!/usr/bin/perl -w

# Copyright 2013, 2014, 2020 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


# Print tikz P,Q points as dots.

use strict;
use Math::PlanePath::PythagoreanTree;

use FindBin;
use lib $FindBin::Bin;
use MyPrintwrap ':all';
use MyTriples 'pq_acceptable';


my $p_limit = 10;
if (@ARGV) {
  $p_limit = $ARGV[0];
}

print "    % generated by tools/$FindBin::Script $p_limit\n";

my $path = Math::PlanePath::PythagoreanTree->new (coordinates => 'PQ');
my $count = 0;

$Printwrap = 4;
printwrap("\\fill foreach \\p in {");
$Printwrap += 2;
foreach my $p (0 .. $p_limit) {
  foreach my $q (0 .. $p) {
    my $got = $path->xy_is_visited($p,$q) ? 1 : 0;
    my $want = pq_acceptable($p,$q) ? 1 : 0;
    $got == $want or die;
    if ($got) {
      printwrap("($p,$q),");
      $count++;
    }
  }
}
printwrap("}");
printwrap(" { \\p circle[] };\n");
print "    % total $count points\n";
print "    % end generated\n";
1;
