#!/usr/bin/perl -w

# Copyright 2013, 2014, 2020 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


# Print a tikz tree which is the Stern-Brocot tree starting at 2,1 and
# filtered to p,q not both odd by a box drawn around the desired both-odd
# points.

use strict;
use Math::PlanePath::RationalsTree;

use FindBin;
use lib $FindBin::Bin;
use MyTriples 'pq_acceptable';


print "  % generated by tools/$FindBin::Script\n";

my $path = Math::PlanePath::RationalsTree->new(tree_type => 'SB');
my $n_top = $path->xy_to_n(2,1);
my $depth_top = $path->tree_n_to_depth($n_top);
my $descend;
$descend = sub {
  my ($n) = @_;
  my $depth = $path->tree_n_to_depth($n) - $depth_top;
  my ($x,$y) = $path->n_to_xy($n);
  my $indent = '  'x$depth;

  my $node = ($n == $n_top ? "\\node" : "node");
  my $draw = (pq_acceptable($x,$y) ? "[draw]" : "");
  if ($n == $n_top) { $draw .= " (p$x$y)"; } # node name
  my $str = ($depth <= 4 ? "$x,$y" : "");
  print "  $indent$node$draw {$str}\n";
  return if $depth >= 5;

  foreach my $n_child ($path->tree_n_children($n)) {
    print "  ${indent}child {\n";
    $descend->($n_child);
    print "  ${indent}}\n";
  }
};
$descend->($n_top);
print "  ;\n";

print "  % end generated\n";
exit 0;
