#!/usr/bin/perl -w

# Copyright 2013, 2014, 2019, 2020 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


# Print tikz trees of UAD, FB, and UMT.

use 5.010;
use strict;
use List::Util 'max','min';
use Math::PlanePath::PythagoreanTree;

use FindBin;
use lib $FindBin::Bin;
use MyTriples ':all';

my $tree_type = $ARGV[0] || 'UAD';

my %m_list = (UAD => ['U','A','D'],
              FB  => ['M1','M2','M3'],
              UMT => ['U','M2','T']);

# could put [child anchor=west] to attach the lines at the deepest
# nodes, looks ok without
#
my $str = <<"HERE"
  % generated by tools/$FindBin::Script $tree_type
HERE
  . <<'HERE';
  \begin{scope}[grow=down,->,
                level 1/.style={sibling distance=11.5em,
                                level distance=9.5ex},
                level 2/.style={sibling distance=3.9em,
                                level distance=9.2ex,
                                font=\scriptsize},
                inner sep=.3em,
                align=center]
    \node at (0,0) [below] {0001}
      child { node {0002}
              child { node {0005}
                      edge from parent
                        node[pos=.6,above left,inner sep=.1em] {00101}
                    }
              child { node {0006}
                      edge from parent
                        node[pos=.45,right,inner sep=.2em] {00102}
                    }
              child { node {0007}
                      edge from parent
                        node[pos=.6,above right,inner sep=.1em] {00103}
                    }
              edge from parent node[pos=.6,above left] {00101}
            }
      child { node {0003}
              child { node {0008}
                      edge from parent
                        node[pos=.6,above left,inner sep=.1em] {00101}
                    }
              child { node {0009}
                      edge from parent
                        node[pos=.45,right,inner sep=.2em] {00102}
                    }
              child { node {0010}
                      edge from parent
                        node[pos=.6,above right,inner sep=.1em] {00103}
                    }
              edge from parent node[pos=.45,right=.1em] {00102} }
      child { node {0004}
              child { node {0011}
                      edge from parent
                        node[pos=.6,above left,inner sep=.1em] {00101}
                    }
              child { node {0012}
                      edge from parent
                        node[pos=.45,right,inner sep=.2em] {00102}
                    }
              child { node {0013}
                      edge from parent
                        node[pos=.6,above right,inner sep=.1em] {00103}
                    }
              edge from parent
                node[pos=.6,above right,name=right-text] {00103} };
  \end{scope}
  % end generated
HERE
my $path_ab = Math::PlanePath::PythagoreanTree->new(tree_type => $tree_type,
                                                    coordinates => 'AB');
my $path_pq = Math::PlanePath::PythagoreanTree->new(tree_type => $tree_type,
                                                    coordinates => 'PQ');
$str =~ s{(00\d+)}
         {
           my $field = $1;
           if ($field < 100) {
             my ($p,$q) = $path_pq->n_to_xy($field);
             my ($a,$b) = $path_ab->n_to_xy($field);
             my $c = sqrt($a*$a+$b*$b);
             "$a,$b,$c \\\\\ {}[$p,$q]"
           } else {
             $m_list{$tree_type}->[$field-101]
           }
         }ge;
print $str;

1;
